diff --git a/Makefile b/Makefile
index e80120e..853b735 100644
--- a/Makefile
+++ b/Makefile
@@ -78,7 +78,11 @@ libx264.a: .depend $(OBJS) $(OBJASM)
 	ranlib libx264.a
 
 $(SONAME): .depend $(OBJS) $(OBJASM)
-	$(CC) -shared -o $@ $(OBJS) $(OBJASM) $(SOFLAGS) $(LDFLAGS)
+        ifeq ($(SYS),MACOSX)
+	    $(CC) -shared -o $@ $(OBJS) $(OBJASM) $(SOFLAGS) $(LDFLAGS) -install_name $(DESTDIR)$(libdir)/$(SONAME$)
+        else
+	    $(CC) -shared -o $@ $(OBJS) $(OBJASM) $(SOFLAGS) $(LDFLAGS)
+        endif
 
 x264$(EXE): $(OBJCLI) libx264.a 
 	$(CC) -o $@ $+ $(LDFLAGS)
@@ -161,7 +165,11 @@ install: x264$(EXE) $(SONAME)
 ifeq ($(SYS),MINGW)
 	$(if $(SONAME), install -m 755 $(SONAME) $(DESTDIR)$(bindir))
 else
-	$(if $(SONAME), ln -sf $(SONAME) $(DESTDIR)$(libdir)/libx264.so)
+        ifeq ($(SYS),MACOSX)
+	    $(if $(SONAME), ln -sf $(SONAME) $(DESTDIR)$(libdir)/libx264.dylib)
+        else
+	    $(if $(SONAME), ln -sf $(SONAME) $(DESTDIR)$(libdir)/libx264.so)
+        endif
 	$(if $(SONAME), install -m 755 $(SONAME) $(DESTDIR)$(libdir))
 endif
 	$(if $(IMPLIBNAME), install -m 644 $(IMPLIBNAME) $(DESTDIR)$(libdir))
@@ -172,7 +180,7 @@ install-gtk: libx264gtk.a
 uninstall:
 	rm -f $(DESTDIR)$(includedir)/x264.h $(DESTDIR)$(libdir)/libx264.a
 	rm -f $(DESTDIR)$(bindir)/x264 $(DESTDIR)$(libdir)/pkgconfig/x264.pc
-	$(if $(SONAME), rm -f $(DESTDIR)$(libdir)/$(SONAME) $(DESTDIR)$(libdir)/libx264.so)
+	$(if $(SONAME), rm -f $(DESTDIR)$(libdir)/$(SONAME) $(DESTDIR)$(libdir)/libx264.so $(DESTDIR)$(libdir)/libx264.dylib)
 	$(MAKE) -C gtk uninstall
 
 etags: TAGS
diff --git a/configure b/configure
index adb2748..b0fd578 100755
--- a/configure
+++ b/configure
@@ -463,7 +463,12 @@ if [ "$shared" = "yes" ]; then
     fi
     echo 'default: $(SONAME)' >> config.mak
     if [ "$gtk" = "yes" ]; then
-        echo "SONAMEGTK=libx264gtk.so.$API" >> gtk/config.mak
+        if [ "$SYS" = "MACOSX" ]; then
+            echo "SONAMEGTK=libx264gtk.$API.dylib" >> gtk/config.mak
+            echo 'SOFLAGS=-dynamiclib -Wl,-single_module -Wl,-read_only_relocs,suppress' >> gtk/config.mak
+        else
+            echo "SONAMEGTK=libx264gtk.so.$API" >> gtk/config.mak
+        fi
     fi
 fi
 
diff --git a/gtk/Makefile b/gtk/Makefile
index 554ff1d..78b3570 100644
--- a/gtk/Makefile
+++ b/gtk/Makefile
@@ -93,7 +93,11 @@ libx264gtk.a: $(OBJECTS_LIB)
 
 $(SONAMEGTK): $(OBJECTS_LIB)
 	@echo "  L: $(@F)"
-	@$(CC) -shared -o $@ $(OBJECTS_LIB) -Wl,-soname,$(SONAMEGTK) $(LDFLAGS)
+        ifeq ($(SYS),MACOSX)
+	    @$(CC) -shared -o $@ $(OBJS) $(OBJASM) $(SOFLAGS) $(LDFLAGS) -install_name $(DESTDIR)$(libdir)/$(SONAMEGTK)
+        else
+	    @$(CC) -shared -o $@ $(OBJECTS_LIB) -Wl,-soname,$(SONAMEGTK) $(LDFLAGS)
+        endif
 
 # Program : test
 $(TEST_BIN): $(OBJECTS_LIB) $(OBJECTS_TEST)
@@ -142,8 +146,13 @@ install: $(ENCODE_BIN)
 	@install -d "$(DESTDIR)$(libdir)"
 	@echo "  I: $(DESTDIR)$(libdir)/libx264gtk.a"
 	@install -m 644 libx264gtk.a "$(DESTDIR)$(libdir)"
-	@echo "  I: $(DESTDIR)$(libdir)/libx264gtk.so"
-	@$(if $(SONAMEGTK), ln -sf $(SONAMEGTK) $(DESTDIR)$(libdir)/libx264gtk.so)
+        ifeq ($(SYS),MACOSX)
+	    @echo "  I: $(DESTDIR)$(libdir)/libx264gtk.dylib"
+	    @$(if $(SONAMEGTK), ln -sf $(SONAMEGTK) $(DESTDIR)$(libdir)/libx264gtk.dylib)
+        else
+	    @echo "  I: $(DESTDIR)$(libdir)/libx264gtk.so"
+	    @$(if $(SONAMEGTK), ln -sf $(SONAMEGTK) $(DESTDIR)$(libdir)/libx264gtk.so)
+        endif
 	@$(if $(SONAMEGTK), install -m 755 $(SONAMEGTK) $(DESTDIR)$(libdir))
 	@echo "  D: $(DESTDIR)$(bindir)"
 	@install -d "$(DESTDIR)$(bindir)"
@@ -172,9 +181,10 @@ uninstall:
 	@rm -f "$(DESTDIR)$(includedir)/x264_gtk_enum.h"
 	@echo "  U: $(DESTDIR)$(libdir)/libx264gtk.a"
 	@rm -f "$(DESTDIR)$(libdir)/libx264gtk.a"
-	@echo "  U: $(DESTDIR)$(libdir)/libx264gtk.so"
+	@echo "  U: $(DESTDIR)$(libdir)/($SONAMEGTK)"
 	@$(if $(SONAMEGTK), rm -f "$(DESTDIR)$(libdir)/$(SONAMEGTK)")
 	@rm -f "$(DESTDIR)$(libdir)/libx264gtk.so"
+	@rm -f "$(DESTDIR)$(libdir)/libx264gtk.dylib"
 	@echo "  U: $(DESTDIR)$(bindir)/$(ENCODE_BIN)"
 	@rm -f "$(DESTDIR)$(bindir)/$(ENCODE_BIN)"
 	@echo "  U: $(DESTDIR)${datadir}/x264"
